==> anwiba-commons-injection-1.0.154-sources.jar: net/anwiba/commons/injection/IValueInjectorBuilder.java <==
/*
 * #%L
 * anwiba commons core
 * %%
 * Copyright (C) 2007 - 2016 Andreas Bartels
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-2.1.html>.
 * #L%
 */

package net.anwiba.commons.injection;

import net.anwiba.commons.reflection.CreationException;

public interface IValueInjectorBuilder {

  <T, S extends T> IValueInjectorBuilder set(Class<T> clazz, S object);

  <T, S extends T> IValueInjectorBuilder add(Class<T> clazz, S object);

  <T> IValueInjectorBuilder set(Class<T> clazz, Class<? extends T> objectClass);

  <T> IValueInjectorBuilder add(Class<T> clazz, Class<? extends T> objectClass);

  <T> IValueInjectorBuilder set(Class<T> clazz, IInjectingFactory<T> objectFactory);

  <T> IValueInjectorBuilder add(Class<T> clazz, IInjectingFactory<T> objectFactory);

  <T> IValueInjectorBuilder link(Class<T> clazz, Class<? extends T> link);

  IValueInjector build() throws CreationException;

}

==> anwiba-commons-injection-1.0.185-sources.jar: net/anwiba/commons/injection/IValueInjectorBuilder.java <==
/*
 * #%L
 * anwiba commons core
 * %%
 * Copyright (C) 2007 - 2016 Andreas Bartels
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-2.1.html>.
 * #L%
 */

package net.anwiba.commons.injection;

import net.anwiba.commons.reflection.CreationException;

public interface IValueInjectorBuilder {

  <T, S extends T> IValueInjectorBuilder set(Class<T> clazz, S object);

  <T, S extends T> IValueInjectorBuilder add(Class<T> clazz, S object);

  <T> IValueInjectorBuilder set(Class<T> clazz, Class<? extends T> objectClass);

  <T> IValueInjectorBuilder add(Class<T> clazz, Class<? extends T> objectClass);

  <T> IValueInjectorBuilder set(Class<T> clazz, IInjectingFactory<T> objectFactory);

  <T> IValueInjectorBuilder add(Class<T> clazz, IInjectingFactory<T> objectFactory);

  <T> IValueInjectorBuilder link(Class<? extends T> clazz, Class<T> link);

  IValueInjector build() throws CreationException;

}
